@@ -6,6 +6,8 @@ import datetime, time, pytz, calendar
 import simplejson as json
 import uuid
 
+import utils
+
 class SourcesGroup(models.Model):
     name = models.CharField(max_length=5000,verbose_name="Common Name")
     external_id = models.CharField(max_length=5000,verbose_name="External Id.")
@@ -41,6 +43,36 @@ class SourcesGroup(models.Model):
 
         return sg
 
+    def to_dict(self,references=False):
+        res = {}
+        res["name"]=self.name
+        res["external_id"]=self.external_id
+        res["default_offset_start"]=self.default_offset_start
+        res["default_offset_end"]=self.default_offset_end
+        res["default_availability_window"]=self.default_availability_window
+        res["insertion_time"]=utils.from_date_to_timestamp(self.insertion_date)
+        res["modification_time"]=utils.from_date_to_timestamp(self.modification_date)
+        res["sources"]=[]
+        for s in self.source_set.all():
+            res["sources"].append(s.to_dict(references=False))
+        return res
+
+    def load_dict(self, d):
+        self.name = d["name"]
+        self.external_id = d["external_id"]
+        self.default_offset_start = d["default_offset_start"]
+        self.default_offset_end = d["default_offset_end"]
+        self.default_availability_window = d["default_availability_window"]
+        self.save()
+        self.source_set.all().delete()
+        if d.has_key("sources") and d["sources"]:
+            for dd in d["sources"]:
+                s = Source()
+                s.sources_group = self
+                s.load_dict(dd)
+
+        self.save()
+
     def save(self, *args, **kwargs):
         if not self.insertion_date:
             d = datetime.datetime.fromtimestamp(time.time(), pytz.UTC)
@@ -92,6 +124,22 @@ class Source(models.Model):
     def __unicode__(self):
         return u"%s [%s] [%s]" % (slugify(self.name), self.uri,self.bitrate)
 
+    def to_dict(self,references=False):
+        res = {}
+        res["name"]=self.name
+        res["uri"]=self.uri
+        res["bitrate"]=self.bitrate
+        res["insertion_time"]=utils.from_date_to_timestamp(self.insertion_date)
+        res["modification_time"]=utils.from_date_to_timestamp(self.modification_date)
+        if references:
+            res["sources_group"]=self.sources_group.id
+        return res
+
+    def load_dict(self, d):
+        self.name = d["name"]
+        self.uri = d["uri"]
+        self.bitrate = d["bitrate"]
+        self.save()
 
 class Recorder(models.Model):
     name = models.CharField(max_length=5000)
@@ -147,6 +195,60 @@ class RecordingSource(models.Model):
             rr_clone.save()
         return rs
 
+    def to_dict(self,references=False):
+        res = {}
+        res["enabled"]=self.enabled
+        res["external_id"]=self.external_id
+
+        if self.sources_group:
+            res["sources_group"]=self.sources_group.to_dict(references=False)
+
+        res["recording_metadata"]=[]
+        rm_list = RecordingMetadata.objects.filter(recording_source=self)
+        for rm in rm_list:
+            res["recording_metadata"].append(rm.to_dict(references=False))
+
+        res["recording_rules"]=[]
+        rr_list = RecordingRule.objects.filter(recording_source=self)
+        for rr in rr_list:
+            res["recording_rules"].append(rr.to_dict(references=False))
+
+        return res
+
+    def load_dict(self, d):
+        # replace new values from d dict in the RecordingSource object deleting
+        # the older values
+        self.external_id = d["external_id"]
+        self.enabled = d["enabled"]
+
+        self.save()
+
+        if d.has_key("sources_group") and d["sources_group"]:
+            try:
+              sg = SourcesGroup.objects.filter(name=d["sources_group"]["name"])[0]
+            except Exception, e:
+              sg = SourcesGroup()
+            self.sources_group = sg
+            self.sources_group.load_dict(d["sources_group"])
+        elif self.sources_group:
+            self.sources_group = None
+
+        RecordingMetadata.objects.filter(recording_source=self).delete()
+        if d.has_key("recording_metadata") and d["recording_metadata"]:
+            for dd in d["recording_metadata"]:
+                rm = RecordingMetadata()
+                rm.recording_source=self
+                rm.load_dict(dd)
+
+        RecordingRule.objects.filter(recording_source=self).delete()
+        if d.has_key("recording_rules") and d["recording_rules"]:
+            for dd in d["recording_rules"]:
+                rr = RecordingRule()
+                rr.recording_source=self
+                rr.load_dict(dd)
+
+        self.save()
+
     def save(self, *args, **kwargs):
         if not self.insertion_date:
             d = datetime.datetime.fromtimestamp(time.time(), pytz.UTC)
@@ -174,6 +276,19 @@ class RecordingMetadata(models.Model):
         rm.save()
         return rm
 
+    def to_dict(self,references=False):
+        res = {}
+        res["key"]=self.key
+        res["value"]=self.value
+        if references:
+            res["recording_source"]=self.recording_source.id
+        return res
+
+    def load_dict(self, d):
+        self.key = d["key"]
+        self.value = d["value"]
+        self.save()
+
     def __repr__(self):
         return self.__unicode__()
 
@@ -205,6 +320,25 @@ class RecordingRule(models.Model):
         rr.save()
         return rr
 
+    def to_dict(self,references=False):
+        res = {}
+        res["metadata_key_filter"]=self.metadata_key_filter
+        res["metadata_value_filter"]=self.metadata_value_filter
+        res["offset_start"]=self.offset_start
+        res["offset_end"]=self.offset_end
+        res["availability_window"]=self.availability_window
+        if references:
+            res["recording_source"]=self.recording_source.id
+        return res
+
+    def load_dict(self, d):
+        self.metadata_key_filter = d["metadata_key_filter"]
+        self.metadata_value_filter = d["metadata_value_filter"]
+        self.offset_start = d["offset_start"]
+        self.offset_end = d["offset_end"]
+        self.availability_window = d["availability_window"]
+        self.save()
+
     def __repr__(self):
         return self.__unicode__()
 
